"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deserializeAws_restJson1InvokeEndpointAsyncCommand = exports.deserializeAws_restJson1InvokeEndpointCommand = exports.serializeAws_restJson1InvokeEndpointAsyncCommand = exports.serializeAws_restJson1InvokeEndpointCommand = void 0;
const protocol_http_1 = require("@aws-sdk/protocol-http");
const smithy_client_1 = require("@aws-sdk/smithy-client");
const models_0_1 = require("../models/models_0");
const SageMakerRuntimeServiceException_1 = require("../models/SageMakerRuntimeServiceException");
const serializeAws_restJson1InvokeEndpointCommand = async (input, context) => {
    const { hostname, protocol = "https", port, path: basePath } = await context.endpoint();
    const headers = {
        "content-type": "application/octet-stream",
        ...(isSerializableHeaderValue(input.ContentType) && { "content-type": input.ContentType }),
        ...(isSerializableHeaderValue(input.Accept) && { accept: input.Accept }),
        ...(isSerializableHeaderValue(input.CustomAttributes) && {
            "x-amzn-sagemaker-custom-attributes": input.CustomAttributes,
        }),
        ...(isSerializableHeaderValue(input.TargetModel) && { "x-amzn-sagemaker-target-model": input.TargetModel }),
        ...(isSerializableHeaderValue(input.TargetVariant) && { "x-amzn-sagemaker-target-variant": input.TargetVariant }),
        ...(isSerializableHeaderValue(input.TargetContainerHostname) && {
            "x-amzn-sagemaker-target-container-hostname": input.TargetContainerHostname,
        }),
        ...(isSerializableHeaderValue(input.InferenceId) && { "x-amzn-sagemaker-inference-id": input.InferenceId }),
    };
    let resolvedPath = `${(basePath === null || basePath === void 0 ? void 0 : basePath.endsWith("/")) ? basePath.slice(0, -1) : basePath || ""}` + "/endpoints/{EndpointName}/invocations";
    if (input.EndpointName !== undefined) {
        const labelValue = input.EndpointName;
        if (labelValue.length <= 0) {
            throw new Error("Empty value provided for input HTTP label: EndpointName.");
        }
        resolvedPath = resolvedPath.replace("{EndpointName}", (0, smithy_client_1.extendedEncodeURIComponent)(labelValue));
    }
    else {
        throw new Error("No value provided for input HTTP label: EndpointName.");
    }
    let body;
    if (input.Body !== undefined) {
        body = input.Body;
    }
    return new protocol_http_1.HttpRequest({
        protocol,
        hostname,
        port,
        method: "POST",
        headers,
        path: resolvedPath,
        body,
    });
};
exports.serializeAws_restJson1InvokeEndpointCommand = serializeAws_restJson1InvokeEndpointCommand;
const serializeAws_restJson1InvokeEndpointAsyncCommand = async (input, context) => {
    const { hostname, protocol = "https", port, path: basePath } = await context.endpoint();
    const headers = {
        ...(isSerializableHeaderValue(input.ContentType) && { "x-amzn-sagemaker-content-type": input.ContentType }),
        ...(isSerializableHeaderValue(input.Accept) && { "x-amzn-sagemaker-accept": input.Accept }),
        ...(isSerializableHeaderValue(input.CustomAttributes) && {
            "x-amzn-sagemaker-custom-attributes": input.CustomAttributes,
        }),
        ...(isSerializableHeaderValue(input.InferenceId) && { "x-amzn-sagemaker-inference-id": input.InferenceId }),
        ...(isSerializableHeaderValue(input.InputLocation) && { "x-amzn-sagemaker-inputlocation": input.InputLocation }),
        ...(isSerializableHeaderValue(input.RequestTTLSeconds) && {
            "x-amzn-sagemaker-requestttlseconds": input.RequestTTLSeconds.toString(),
        }),
    };
    let resolvedPath = `${(basePath === null || basePath === void 0 ? void 0 : basePath.endsWith("/")) ? basePath.slice(0, -1) : basePath || ""}` +
        "/endpoints/{EndpointName}/async-invocations";
    if (input.EndpointName !== undefined) {
        const labelValue = input.EndpointName;
        if (labelValue.length <= 0) {
            throw new Error("Empty value provided for input HTTP label: EndpointName.");
        }
        resolvedPath = resolvedPath.replace("{EndpointName}", (0, smithy_client_1.extendedEncodeURIComponent)(labelValue));
    }
    else {
        throw new Error("No value provided for input HTTP label: EndpointName.");
    }
    let body;
    return new protocol_http_1.HttpRequest({
        protocol,
        hostname,
        port,
        method: "POST",
        headers,
        path: resolvedPath,
        body,
    });
};
exports.serializeAws_restJson1InvokeEndpointAsyncCommand = serializeAws_restJson1InvokeEndpointAsyncCommand;
const deserializeAws_restJson1InvokeEndpointCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return deserializeAws_restJson1InvokeEndpointCommandError(output, context);
    }
    const contents = {
        $metadata: deserializeMetadata(output),
        Body: undefined,
        ContentType: undefined,
        CustomAttributes: undefined,
        InvokedProductionVariant: undefined,
    };
    if (output.headers["content-type"] !== undefined) {
        contents.ContentType = output.headers["content-type"];
    }
    if (output.headers["x-amzn-invoked-production-variant"] !== undefined) {
        contents.InvokedProductionVariant = output.headers["x-amzn-invoked-production-variant"];
    }
    if (output.headers["x-amzn-sagemaker-custom-attributes"] !== undefined) {
        contents.CustomAttributes = output.headers["x-amzn-sagemaker-custom-attributes"];
    }
    const data = await collectBody(output.body, context);
    contents.Body = data;
    return Promise.resolve(contents);
};
exports.deserializeAws_restJson1InvokeEndpointCommand = deserializeAws_restJson1InvokeEndpointCommand;
const deserializeAws_restJson1InvokeEndpointCommandError = async (output, context) => {
    const parsedOutput = {
        ...output,
        body: await parseBody(output.body, context),
    };
    let response;
    let errorCode = "UnknownError";
    errorCode = loadRestJsonErrorCode(output, parsedOutput.body);
    switch (errorCode) {
        case "InternalDependencyException":
        case "com.amazonaws.sagemakerruntime#InternalDependencyException":
            throw await deserializeAws_restJson1InternalDependencyExceptionResponse(parsedOutput, context);
        case "InternalFailure":
        case "com.amazonaws.sagemakerruntime#InternalFailure":
            throw await deserializeAws_restJson1InternalFailureResponse(parsedOutput, context);
        case "ModelError":
        case "com.amazonaws.sagemakerruntime#ModelError":
            throw await deserializeAws_restJson1ModelErrorResponse(parsedOutput, context);
        case "ModelNotReadyException":
        case "com.amazonaws.sagemakerruntime#ModelNotReadyException":
            throw await deserializeAws_restJson1ModelNotReadyExceptionResponse(parsedOutput, context);
        case "ServiceUnavailable":
        case "com.amazonaws.sagemakerruntime#ServiceUnavailable":
            throw await deserializeAws_restJson1ServiceUnavailableResponse(parsedOutput, context);
        case "ValidationError":
        case "com.amazonaws.sagemakerruntime#ValidationError":
            throw await deserializeAws_restJson1ValidationErrorResponse(parsedOutput, context);
        default:
            const parsedBody = parsedOutput.body;
            response = new SageMakerRuntimeServiceException_1.SageMakerRuntimeServiceException({
                name: parsedBody.code || parsedBody.Code || errorCode,
                $fault: "client",
                $metadata: deserializeMetadata(output),
            });
            throw (0, smithy_client_1.decorateServiceException)(response, parsedBody);
    }
};
const deserializeAws_restJson1InvokeEndpointAsyncCommand = async (output, context) => {
    if (output.statusCode !== 202 && output.statusCode >= 300) {
        return deserializeAws_restJson1InvokeEndpointAsyncCommandError(output, context);
    }
    const contents = {
        $metadata: deserializeMetadata(output),
        InferenceId: undefined,
        OutputLocation: undefined,
    };
    if (output.headers["x-amzn-sagemaker-outputlocation"] !== undefined) {
        contents.OutputLocation = output.headers["x-amzn-sagemaker-outputlocation"];
    }
    const data = (0, smithy_client_1.expectNonNull)((0, smithy_client_1.expectObject)(await parseBody(output.body, context)), "body");
    if (data.InferenceId !== undefined && data.InferenceId !== null) {
        contents.InferenceId = (0, smithy_client_1.expectString)(data.InferenceId);
    }
    return Promise.resolve(contents);
};
exports.deserializeAws_restJson1InvokeEndpointAsyncCommand = deserializeAws_restJson1InvokeEndpointAsyncCommand;
const deserializeAws_restJson1InvokeEndpointAsyncCommandError = async (output, context) => {
    const parsedOutput = {
        ...output,
        body: await parseBody(output.body, context),
    };
    let response;
    let errorCode = "UnknownError";
    errorCode = loadRestJsonErrorCode(output, parsedOutput.body);
    switch (errorCode) {
        case "InternalFailure":
        case "com.amazonaws.sagemakerruntime#InternalFailure":
            throw await deserializeAws_restJson1InternalFailureResponse(parsedOutput, context);
        case "ServiceUnavailable":
        case "com.amazonaws.sagemakerruntime#ServiceUnavailable":
            throw await deserializeAws_restJson1ServiceUnavailableResponse(parsedOutput, context);
        case "ValidationError":
        case "com.amazonaws.sagemakerruntime#ValidationError":
            throw await deserializeAws_restJson1ValidationErrorResponse(parsedOutput, context);
        default:
            const parsedBody = parsedOutput.body;
            response = new SageMakerRuntimeServiceException_1.SageMakerRuntimeServiceException({
                name: parsedBody.code || parsedBody.Code || errorCode,
                $fault: "client",
                $metadata: deserializeMetadata(output),
            });
            throw (0, smithy_client_1.decorateServiceException)(response, parsedBody);
    }
};
const deserializeAws_restJson1InternalDependencyExceptionResponse = async (parsedOutput, context) => {
    const contents = {};
    const data = parsedOutput.body;
    if (data.Message !== undefined && data.Message !== null) {
        contents.Message = (0, smithy_client_1.expectString)(data.Message);
    }
    const exception = new models_0_1.InternalDependencyException({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return (0, smithy_client_1.decorateServiceException)(exception, parsedOutput.body);
};
const deserializeAws_restJson1InternalFailureResponse = async (parsedOutput, context) => {
    const contents = {};
    const data = parsedOutput.body;
    if (data.Message !== undefined && data.Message !== null) {
        contents.Message = (0, smithy_client_1.expectString)(data.Message);
    }
    const exception = new models_0_1.InternalFailure({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return (0, smithy_client_1.decorateServiceException)(exception, parsedOutput.body);
};
const deserializeAws_restJson1ModelErrorResponse = async (parsedOutput, context) => {
    const contents = {};
    const data = parsedOutput.body;
    if (data.LogStreamArn !== undefined && data.LogStreamArn !== null) {
        contents.LogStreamArn = (0, smithy_client_1.expectString)(data.LogStreamArn);
    }
    if (data.Message !== undefined && data.Message !== null) {
        contents.Message = (0, smithy_client_1.expectString)(data.Message);
    }
    if (data.OriginalMessage !== undefined && data.OriginalMessage !== null) {
        contents.OriginalMessage = (0, smithy_client_1.expectString)(data.OriginalMessage);
    }
    if (data.OriginalStatusCode !== undefined && data.OriginalStatusCode !== null) {
        contents.OriginalStatusCode = (0, smithy_client_1.expectInt32)(data.OriginalStatusCode);
    }
    const exception = new models_0_1.ModelError({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return (0, smithy_client_1.decorateServiceException)(exception, parsedOutput.body);
};
const deserializeAws_restJson1ModelNotReadyExceptionResponse = async (parsedOutput, context) => {
    const contents = {};
    const data = parsedOutput.body;
    if (data.Message !== undefined && data.Message !== null) {
        contents.Message = (0, smithy_client_1.expectString)(data.Message);
    }
    const exception = new models_0_1.ModelNotReadyException({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return (0, smithy_client_1.decorateServiceException)(exception, parsedOutput.body);
};
const deserializeAws_restJson1ServiceUnavailableResponse = async (parsedOutput, context) => {
    const contents = {};
    const data = parsedOutput.body;
    if (data.Message !== undefined && data.Message !== null) {
        contents.Message = (0, smithy_client_1.expectString)(data.Message);
    }
    const exception = new models_0_1.ServiceUnavailable({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return (0, smithy_client_1.decorateServiceException)(exception, parsedOutput.body);
};
const deserializeAws_restJson1ValidationErrorResponse = async (parsedOutput, context) => {
    const contents = {};
    const data = parsedOutput.body;
    if (data.Message !== undefined && data.Message !== null) {
        contents.Message = (0, smithy_client_1.expectString)(data.Message);
    }
    const exception = new models_0_1.ValidationError({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return (0, smithy_client_1.decorateServiceException)(exception, parsedOutput.body);
};
const deserializeMetadata = (output) => {
    var _a;
    return ({
        httpStatusCode: output.statusCode,
        requestId: (_a = output.headers["x-amzn-requestid"]) !== null && _a !== void 0 ? _a : output.headers["x-amzn-request-id"],
        extendedRequestId: output.headers["x-amz-id-2"],
        cfId: output.headers["x-amz-cf-id"],
    });
};
const collectBody = (streamBody = new Uint8Array(), context) => {
    if (streamBody instanceof Uint8Array) {
        return Promise.resolve(streamBody);
    }
    return context.streamCollector(streamBody) || Promise.resolve(new Uint8Array());
};
const collectBodyString = (streamBody, context) => collectBody(streamBody, context).then((body) => context.utf8Encoder(body));
const isSerializableHeaderValue = (value) => value !== undefined &&
    value !== null &&
    value !== "" &&
    (!Object.getOwnPropertyNames(value).includes("length") || value.length != 0) &&
    (!Object.getOwnPropertyNames(value).includes("size") || value.size != 0);
const parseBody = (streamBody, context) => collectBodyString(streamBody, context).then((encoded) => {
    if (encoded.length) {
        return JSON.parse(encoded);
    }
    return {};
});
const loadRestJsonErrorCode = (output, data) => {
    const findKey = (object, key) => Object.keys(object).find((k) => k.toLowerCase() === key.toLowerCase());
    const sanitizeErrorCode = (rawValue) => {
        let cleanValue = rawValue;
        if (cleanValue.indexOf(":") >= 0) {
            cleanValue = cleanValue.split(":")[0];
        }
        if (cleanValue.indexOf("#") >= 0) {
            cleanValue = cleanValue.split("#")[1];
        }
        return cleanValue;
    };
    const headerKey = findKey(output.headers, "x-amzn-errortype");
    if (headerKey !== undefined) {
        return sanitizeErrorCode(output.headers[headerKey]);
    }
    if (data.code !== undefined) {
        return sanitizeErrorCode(data.code);
    }
    if (data["__type"] !== undefined) {
        return sanitizeErrorCode(data["__type"]);
    }
    return "";
};
